{% extends "admin/base.html" %}
{% load shuyucms_tags i18n future staticfiles %}

{% block title %}{{ title }} | shuyucms{% endblock %}

{% block extrahead %}
<link rel="stylesheet" href="{% static "shuyucms/css/admin/global.css" %}">
<style>
    /* These are set in PageAdmin's view methods, and shuyucms.core.admin.SingletonAdmin */
    {% if hide_delete_link or singleton %}.submit-row .deletelink {display:none !important;}{% endif %}
    {% if hide_slug_field %}.slug {display:none !important;}{% endif %}
    {% if singleton %}.change-view-save-another {display:none !important;}{% endif %}
</style>
<script>
    {% url "static_proxy" as static_proxy_url %}
    {% url "fb_browse" as fb_browse_url %}
    {% url "admin:index" as admin_index_url %}
    {% get_current_language as LANGUAGE_CODE %}
    window.__home_link = '<a href="{% url "home" %}">{% trans "View site" %}</a>';
    window.__csrf_token = '{{ csrf_token }}';
    window.__admin_keywords_submit_url = '{% url "admin_keywords_submit" %}';
    window.__syfilebrowser_url = '{{ fb_browse_url }}';
    window.__tinymce_css = '{% static "shuyucms/css/tinymce.css" %}';
    window.__admin_url = '{{ admin_index_url }}';
    window.__static_proxy = '{{ static_proxy_url }}';
    window.__admin_media_prefix__ = '{% static "admin" %}/';
    window.__wladmin_installed = {{ settings.WLADMIN_INSTALLED|default:"true"|lower }};
    window.__admin_menu_collapsed = {{ settings.ADMIN_MENU_COLLAPSED|default:"false"|lower }};
    window.__language_code = '{{ LANGUAGE_CODE }}';
</script>

{% if not settings.WLADMIN_INSTALLED %}
<script src="{% static "shuyucms/js/"|add:settings.JQUERY_FILENAME %}"></script>
{% endif %}

<script>
jQuery(function($) {
    $('.admin-title').click(function() {location = window.__admin_url;});
});
</script>

{% endblock %}

{% block rtl_styles %}
{{ block.super }}
<link rel="stylesheet" type="text/css" href="{% static "shuyucms/css/admin/rtl.css" %}" />
{% endblock %}

{% block before_content %}
{% if user.is_staff and not is_popup and not request.GET.pop %}
{% admin_dropdown_menu %}
{% endif %}
{% endblock %}

{% block footer %}
{% if form.this_is_the_login_form %}
    <script src="{% static "shuyucms/js/admin/login.js" %}"></script>
{% else %}
    {% if user.is_staff %}
        {% if not is_popup and not request.GET.pop %}
        <link rel="stylesheet" href="{% static "shuyucms/chosen/chosen.css" %}">
        <script src="{% static "shuyucms/chosen/chosen-0.9.12.jquery.js" %}"></script>
        <script src="{% static "shuyucms/js/admin/navigation.js" %}"></script>

        {% endif %}
        <script src="{% static "shuyucms/js/admin/ajax_csrf.js" %}"></script>
        {% if settings.WLADMIN_INSTALLED %}
        <script src="{% static "shuyucms/js/admin/collapse_backport.js" %}"></script>
        {% endif %}
    {% endif %}
{% endif %}
{% endblock %}
