<!doctype html>
<html lang="{{ LANGUAGE_CODE }}"{% if LANGUAGE_BIDI %} dir="rtl"{% endif %}>
{% load pages_tags shuyucms_tags i18n future staticfiles %}

<head>
<meta http-equiv="Content-type" content="text/html; charset=utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta name="keywords" content="{% block meta_keywords %}{% endblock %}">
<meta name="description" content="{% block meta_description %}{% endblock %}">
<title>{% block meta_title %}{% endblock %}{% if settings.SITE_TITLE %} | {{ settings.SITE_TITLE }}{% endif %}</title>
<link rel="shortcut icon" href="{% static "img/favicon.ico" %}">

{% ifinstalled shuyucms.blog %}
<link rel="alternate" type="application/rss+xml" title="RSS" href="{% url "blog_post_feed" "rss" %}">
<link rel="alternate" type="application/atom+xml" title="Atom" href="{% url "blog_post_feed" "atom" %}">
{% endifinstalled %}

{% compress css %}
<link rel="stylesheet" href="{% static "css/bootstrap.css" %}">
<link rel="stylesheet" href="{% static "css/shuyucms.css" %}">
<link rel="stylesheet" href="{% static "css/bootstrap-theme.css" %}">
{% if LANGUAGE_BIDI %}
<link rel="stylesheet" href="{% static "css/rtl.css" %}">
{% endif %}
{% ifinstalled cartridge.shop %}
<link rel="stylesheet" href="{% static "css/cartridge.css" %}">
{% if LANGUAGE_BIDI %}
<link rel="stylesheet" href="{% static "css/cartridge.rtl.css" %}">
{% endif %}
{% endifinstalled %}
{% block extra_css %}{% endblock %}
{% endcompress %}

{% compress js %}
<script src="{% static "shuyucms/js/"|add:settings.JQUERY_FILENAME %}"></script>
<script src="{% static "js/bootstrap.js" %}"></script>
<script src="{% static "js/bootstrap-extras.js" %}"></script>
{% block extra_js %}{% endblock %}
{% endcompress %}

<!--[if lt IE 9]>
<script src="{% static "js/html5shiv.js" %}"></script>
<script src="{% static "js/respond.min.js" %}"></script>
<![endif]-->

{% block extra_head %}{% endblock %}
</head>

<body id="{% block body_id %}body{% endblock %}">

<div class="navbar navbar-default navbar-fixed-top" role="navigation">
<div class="container">
<div class="navbar-header">
    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
        <span class="sr-only">{% trans "Toggle Navigation" %}</span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
    </button>
    {% if settings.SITE_TITLE %}<a class="navbar-brand" href="/">{{ settings.SITE_TITLE }}</a>{% endif %}
    {% if settings.SITE_TAGLINE %}<p class="navbar-text visible-lg">{{ settings.SITE_TAGLINE }}</p>{% endif %}
</div>
<div class="navbar-collapse collapse">
    {% search_form "all" %}
    {% page_menu "pages/menus/dropdown.html" %}
</div>
</div>
</div>

<div class="container">

{% nevercache %}
{% if messages %}
<div class="messages">
{% for message in messages %}
<div class="alert alert-dismissable alert-{{ message.tags }}" data-alert="alert">
    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
    {{ message }}
</div>
{% endfor %}
</div>
{% endif %}
{% endnevercache %}

<h1>{% block title %}{% endblock %}</h1>

<ul class="breadcrumb">
{% spaceless %}
{% block breadcrumb_menu %}{% page_menu "pages/menus/breadcrumb.html" %}{% endblock %}
{% endspaceless %}
</ul>

</div>

<div class="container">
<div class="row">

<div class="col-md-2 left">
    {% block left_panel %}
    <div class="panel panel-default tree">{% page_menu "pages/menus/tree.html" %}</div>
    {% endblock %}
</div>

<div class="col-md-7 middle">
    {% block main %}{% endblock %}
</div>

<div class="col-md-3 right">
    {% nevercache %}
    {% include "includes/user_panel.html" %}
    {% endnevercache %}
    <div class="panel panel-default">
    <div class="panel-body">
    {% block right_panel %}
    {% ifinstalled shuyucms.twitter %}
    {% include "twitter/tweets.html" %}
    {% endifinstalled %}
    {% endblock %}
    </div>
    </div>
</div>

</div>
</div>

<footer>
<div class="container">
{% page_menu "pages/menus/footer.html" %}

<div class="row">
<p class="site-info text-center">
    {% trans "Powered by" %}
    <a href="http://shuyucms.jupo.org">shuyucms</a>{% ifinstalled cartridge.shop %},
    <a href="http://cartridge.jupo.org">Cartridge</a>{% endifinstalled %}
    {% trans "and" %}
    <a href="http://www.djangoproject.com">Django</a>
    <span class="separator">|</span>
    {% trans "Theme by" %} <a target="_blank" href="http://getbootstrap.com">Bootstrap</a>
    {% ifinstalled shuyucms.mobile %}
    <span class="separator">|</span>
    <a href="{% url "set_device" "mobile" %}?next={{ request.path }}">{% trans "View Mobile Site" %}</a>
    {% endifinstalled %}
</p>
</div>
</div>
</footer>

{% include "includes/footer_scripts.html" %}

</body>
</html>
