{% extends "base.html" %}

{% load i18n %}

{% block meta_title %}
{% trans "Page not found" %}
{% endblock %}

{% block title %}
{% trans "Page not found" %}
{% endblock %}

{% block main %}
<div class="panel panel-danger">
	<div class="panel-heading"><h3 class="panel-title">{% trans "Page not found" %}</h3></div>
	<div class="panel-body">{% trans "The page you requested does not exist." %}</div>
</div>
{% endblock %}
